@@ -1,7 +1,7 @@
 package Bencher::Scenario::ArgPassing::Mixed;
 
-our $DATE = '2017-01-23'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2017-01-25'; # DATE
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -79,7 +79,7 @@ Bencher::Scenario::ArgPassing::Mixed - Benchmark argument passing (mixed positio
 
 =head1 VERSION
 
-This document describes version 0.002 of Bencher::Scenario::ArgPassing::Mixed (from Perl distribution Bencher-Scenarios-ArgPassing), released on 2017-01-23.
+This document describes version 0.003 of Bencher::Scenario::ArgPassing::Mixed (from Perl distribution Bencher-Scenarios-ArgPassing), released on 2017-01-25.
 
 =head1 SYNOPSIS
 
@@ -167,12 +167,12 @@ Benchmark with default options (C<< bencher -m ArgPassing::Mixed >>):
  +--------------------------+---------------+-----------+-----------+------------+---------+---------+
  | participant              | dataset       | rate (/s) | time (μs) | vs_slowest |  errors | samples |
  +--------------------------+---------------+-----------+-----------+------------+---------+---------+
- | list_then_hash           | pos=3 named=5 |    634320 |  1.5765   |    1       | 9.5e-12 |      20 |
- | list_then_hash           | pos=3 named=1 |   1319820 |  0.757677 |    2.0807  |   0     |      20 |
- | opt_hashref_at_the_front | pos=3 named=5 |   1391360 |  0.718721 |    2.19348 |   0     |      20 |
- | hashref_at_the_front     | pos=3 named=5 |   1515030 |  0.660054 |    2.38844 |   0     |      20 |
- | opt_hashref_at_the_front | pos=3 named=1 |   2245000 |  0.4454   |    3.54    | 9.7e-12 |      20 |
- | hashref_at_the_front     | pos=3 named=1 |   2600000 |  0.39     |    4.1     | 5.6e-10 |      25 |
+ | list_then_hash           | pos=3 named=5 |    650000 |   1.5     |    1       | 2.9e-09 |      27 |
+ | list_then_hash           | pos=3 named=1 |   1350000 |   0.742   |    2.08    | 3.2e-10 |      34 |
+ | opt_hashref_at_the_front | pos=3 named=5 |   1376000 |   0.727   |    2.125   | 3.1e-11 |      20 |
+ | hashref_at_the_front     | pos=3 named=5 |   1465000 |   0.6824  |    2.264   |   1e-11 |      20 |
+ | opt_hashref_at_the_front | pos=3 named=1 |   2272470 |   0.44005 |    3.51039 |   0     |      20 |
+ | hashref_at_the_front     | pos=3 named=1 |   2567000 |   0.3895  |    3.966   | 1.1e-11 |      21 |
  +--------------------------+---------------+-----------+-----------+------------+---------+---------+
 
 
