@@ -1,6 +1,6 @@
 package Bencher::ScenarioR::ArgPassing::Mixed;
 
-our $VERSION = 0.002; # VERSION
+our $VERSION = 0.003; # VERSION
 
 our $results = [
   [
@@ -9,57 +9,57 @@ our $results = [
     [
       {
         dataset     => "pos=3 named=5",
-        errors      => 9.5e-12,
+        errors      => 2.9e-09,
         participant => "list_then_hash",
-        rate        => 634320,
-        samples     => 20,
-        time        => 1.5765,
+        rate        => 650000,
+        samples     => 27,
+        time        => 1.5,
         vs_slowest  => 1,
       },
       {
         dataset     => "pos=3 named=1",
-        errors      => 0,
+        errors      => 3.2e-10,
         participant => "list_then_hash",
-        rate        => 1319820,
-        samples     => 20,
-        time        => 0.757677,
-        vs_slowest  => 2.0807,
+        rate        => 1350000,
+        samples     => 34,
+        time        => 0.742,
+        vs_slowest  => 2.08,
       },
       {
         dataset     => "pos=3 named=5",
-        errors      => 0,
+        errors      => 3.1e-11,
         participant => "opt_hashref_at_the_front",
-        rate        => 1391360,
+        rate        => 1376000,
         samples     => 20,
-        time        => 0.718721,
-        vs_slowest  => 2.19348,
+        time        => 0.727,
+        vs_slowest  => 2.125,
       },
       {
         dataset     => "pos=3 named=5",
+        errors      => 1e-11,
+        participant => "hashref_at_the_front",
+        rate        => 1465000,
+        samples     => 20,
+        time        => 0.6824,
+        vs_slowest  => 2.264,
+      },
+      {
+        dataset     => "pos=3 named=1",
         errors      => 0,
-        participant => "hashref_at_the_front",
-        rate        => 1515030,
-        samples     => 20,
-        time        => 0.660054,
-        vs_slowest  => 2.38844,
-      },
-      {
-        dataset     => "pos=3 named=1",
-        errors      => 9.7e-12,
         participant => "opt_hashref_at_the_front",
-        rate        => 2245000,
+        rate        => 2272470,
         samples     => 20,
-        time        => 0.4454,
-        vs_slowest  => 3.54,
+        time        => 0.44005,
+        vs_slowest  => 3.51039,
       },
       {
         dataset     => "pos=3 named=1",
-        errors      => 5.6e-10,
+        errors      => 1.1e-11,
         participant => "hashref_at_the_front",
-        rate        => 2600000,
-        samples     => 25,
-        time        => 0.39,
-        vs_slowest  => 4.1,
+        rate        => 2567000,
+        samples     => 21,
+        time        => 0.3895,
+        vs_slowest  => 3.966,
       },
     ],
     {
@@ -182,7 +182,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 0,
-                                              speed                        => "2851.460",
+                                              speed                        => 2640.039,
                                               stepping                     => 4,
                                             },
                                             {
@@ -297,7 +297,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 1,
-                                              speed                        => 2601.812,
+                                              speed                        => 2862.398,
                                               stepping                     => 4,
                                             },
                                             {
@@ -412,7 +412,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 2,
-                                              speed                        => 2885.476,
+                                              speed                        => 2716.656,
                                               stepping                     => 4,
                                             },
                                             {
@@ -527,13 +527,14 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 3,
-                                              speed                        => 2600.718,
+                                              speed                        => 2886.406,
                                               stepping                     => 4,
                                             },
                                           ],
-      "func.elapsed_time"              => 0.157994985580444,
+      "func.elapsed_time"              => 0.147753000259399,
       "func.module_startup"            => undef,
       "func.module_versions"           => {
+                                            "__PACKAGE__" => 1.034,
                                             "Bencher::Scenario::ArgPassing::Mixed" => undef,
                                             "Benchmark::Dumb" => "0.10",
                                             "Devel::Platform::Info" => 0.16,
@@ -571,9 +572,9 @@ our $results = [
       "func.scenario_module_mtime"     => 1485170687,
       "func.scenario_module_sha1sum"   => "450b615deaabdff2757ac2eb42d877a288c9cdf1",
       "func.scenario_module_sha256sum" => "87a8abedb6bf719923bea62933de5314d2ba61e3adb8db1f02b4a36996498007",
-      "func.time_end"                  => 1485183459.07958,
+      "func.time_end"                  => 1485326795.37981,
       "func.time_factor"               => 1000000,
-      "func.time_start"                => 1485183458.92158,
+      "func.time_start"                => 1485326795.23205,
       "table.field_aligns"             => ["left", "left", "number", "number", "number", "number", "number"],
       "table.field_units"              => [undef, undef, "/s", "\x{3BC}s"],
       "table.fields"                   => [
