@@ -1,6 +1,6 @@
 package Bencher::ScenarioR::ArgPassing::NamedVsPos;
 
-our $VERSION = 0.002; # VERSION
+our $VERSION = 0.003; # VERSION
 
 our $results = [
   [
@@ -9,57 +9,57 @@ our $results = [
     [
       {
         dataset     => "args=10",
-        errors      => 3.3e-09,
+        errors      => 0,
         participant => "named",
-        rate        => 500000,
+        rate        => 554247,
         samples     => 20,
-        time        => 2,
+        time        => 1.80425,
         vs_slowest  => 1,
       },
       {
         dataset     => "args=5",
-        errors      => 3.6e-11,
+        errors      => 1e-11,
         participant => "named",
-        rate        => 875100,
+        rate        => 978110,
         samples     => 20,
-        time        => 1.143,
-        vs_slowest  => 1.758,
+        time        => 1.0224,
+        vs_slowest  => 1.7647,
       },
       {
         dataset     => "args=1",
-        errors      => 2.1e-10,
+        errors      => 8.3e-10,
         participant => "named",
-        rate        => 2040000,
+        rate        => 2300000,
         samples     => 20,
-        time        => 0.489,
+        time        => 0.44,
         vs_slowest  => 4.1,
       },
       {
         dataset     => "args=10",
-        errors      => 1.6e-10,
+        errors      => 0,
         participant => "positional",
-        rate        => 2450000,
-        samples     => 32,
-        time        => 0.408,
-        vs_slowest  => 4.92,
+        rate        => 2705570,
+        samples     => 20,
+        time        => 0.369609,
+        vs_slowest  => 4.88152,
       },
       {
         dataset     => "args=5",
-        errors      => 8.3e-10,
+        errors      => 4.2e-10,
         participant => "positional",
-        rate        => 3300000,
+        rate        => 3700000,
         samples     => 20,
-        time        => 0.3,
+        time        => 0.27,
         vs_slowest  => 6.7,
       },
       {
         dataset     => "args=1",
-        errors      => 5.2e-10,
+        errors      => 3.1e-10,
         participant => "positional",
-        rate        => 4900000,
+        rate        => 5300000,
         samples     => 20,
-        time        => 0.2,
-        vs_slowest  => 9.8,
+        time        => 0.19,
+        vs_slowest  => 9.6,
       },
     ],
     {
@@ -182,7 +182,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 0,
-                                              speed                        => "2748.320",
+                                              speed                        => 2879.023,
                                               stepping                     => 4,
                                             },
                                             {
@@ -297,7 +297,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 1,
-                                              speed                        => 2848.617,
+                                              speed                        => 2869.343,
                                               stepping                     => 4,
                                             },
                                             {
@@ -412,7 +412,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 2,
-                                              speed                        => 2639.765,
+                                              speed                        => 2599.953,
                                               stepping                     => 4,
                                             },
                                             {
@@ -527,13 +527,14 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 3,
-                                              speed                        => 2742.085,
+                                              speed                        => "2851.460",
                                               stepping                     => 4,
                                             },
                                           ],
-      "func.elapsed_time"              => 0.153034925460815,
+      "func.elapsed_time"              => 0.158452987670898,
       "func.module_startup"            => undef,
       "func.module_versions"           => {
+                                            "__PACKAGE__" => 1.034,
                                             "Bencher::Scenario::ArgPassing::NamedVsPos" => undef,
                                             "Benchmark::Dumb" => "0.10",
                                             "Devel::Platform::Info" => 0.16,
@@ -571,9 +572,9 @@ our $results = [
       "func.scenario_module_mtime"     => 1485183386,
       "func.scenario_module_sha1sum"   => "639850f8e518a81c05838c9dabead1dd03bd4a70",
       "func.scenario_module_sha256sum" => "9c7cabc7b8675afa04153b8d9a9bbd3736e910431d501a7c852d3883a6ce9eba",
-      "func.time_end"                  => 1485183459.41412,
+      "func.time_end"                  => 1485326795.71584,
       "func.time_factor"               => 1000000,
-      "func.time_start"                => 1485183459.26108,
+      "func.time_start"                => 1485326795.55738,
       "table.field_aligns"             => ["left", "left", "number", "number", "number", "number", "number"],
       "table.field_units"              => [undef, undef, "/s", "\x{3BC}s"],
       "table.fields"                   => [
